/*-----------------------------------------------------------------------------
 * Name:    ADC_STM32072B-EVAL.c
 * Purpose: ADC interface for STM32072B-EVAL board
 * Rev.:    1.0.0
 *----------------------------------------------------------------------------*/

/* Copyright (c) 2013 - 2017 ARM LIMITED

   All rights reserved.
   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions are met:
   - Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
   - Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
   - Neither the name of ARM nor the names of its contributors may be used
     to endorse or promote products derived from this software without
     specific prior written permission.
   *
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
   AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
   ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDERS AND CONTRIBUTORS BE
   LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
   CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
   SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
   INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
   CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
   ---------------------------------------------------------------------------*/

/*! \page stm32072b_eval_bsi_adc ADC BSI Setup

The BSI ADC requires:
  - Configuration of ADC1 peripheral
  - Setup of pin used by ADC
  - Configuration of ADC1 clock
 
Pinout tab
----------
  1. Select <b>ADC1_IN10</b> IN10 Single-ended
  2. Click on <b>PC0</b> pin and select <b>ADC1_IN10</b> function
 

Configuration tab
-----------------
  1. Under Connectivity open \b ADC1 Configuration:
     - <b>Parameter Settings</b>: review settings, no changes required
     - <b>User Constants</b>: not used
     - <b>NVIC Settings</b>: disable interrupt
          Interrupt Table          | Enable | Preemption Priority | Sub Priority
          :------------------------|:-------|:--------------------|:------------
          ADC1 and ADC2 interrupts | \b OFF | 0                   | 0
     - <b>DMA Settings</b>: disabled
     - <b>GPIO Settings</b>: review settings, no changes required
          Pin Name | Signal on Pin | GPIO out..| GPIO mode   | GPIO Pull-up/Pull..| Maximum out | Fast Mode | User Label
          :--------|:--------------|:----------|:------------|:-------------------|:------------|:----------|:----------
          PC0      | ADC1_IN10     | n/a       | Analog mode | No pull-up and no..| n/a         | n/a       |.
     Click \b OK to close the ADC1 Configuration dialog
*/

#include "Board_ADC.h"                  // ::Board Support:A/D Converter

#include "stm32f0xx_hal.h"              // Device HAL
#include "MX_Device.h"

/* ------------------------------- Configuration ---------------------------- */
#define ADC_INSTANCE_HANDLE             hadc
#define ADC_RESOLUTION                  12U

#ifndef HAL_ADC_MODULE_ENABLED
  #error "::Device:STM32Cube Framework (API): STM32CubeMX: Enable ADC1 IN10!"
#endif

#ifndef MX_ADC_IN10_Pin
  #error "::Device:STM32Cube Framework (API): STM32CubeMX: Set pin PC1 to ADC1_IN10 function!"
#endif
/* -------------------------------------------------------------------------- */

extern ADC_HandleTypeDef ADC_INSTANCE_HANDLE;


/**
  \fn          int32_t ADC_Initialize (void)
  \brief       Initialize buttons
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t ADC_Initialize (void) {

  // All initialization code is generated by CubeMX
  return 0;
}

/**
  \fn          int32_t ADC_Uninitialize (void)
  \brief       De-initialize Analog-to-Digital Converter
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t ADC_Uninitialize (void) {

  // All de-initialization code is generated by CubeMX
  return 0;
}

/**
  \fn          int32_t ADC_StartConversion (void)
  \brief       Start conversion
  \returns
   - \b  0: function succeeded
   - \b -1: function failed
*/
int32_t ADC_StartConversion (void) {

  if (HAL_ADC_Start(&ADC_INSTANCE_HANDLE) != HAL_OK) {
    return -1;
  }

  return 0;
}

/**
  \fn          int32_t ADC_ConversionDone (void)
  \brief       Check if conversion finished
  \returns
   - \b  0: conversion finished
   - \b -1: conversion in progress
*/
int32_t ADC_ConversionDone (void) {

  if (HAL_ADC_PollForConversion(&ADC_INSTANCE_HANDLE, 0U) != HAL_OK) {
    return -1;
  }

  return 0;
}

/**
  \fn          int32_t ADC_GetValue (void)
  \brief       Get converted value
  \returns
   - <b> >=0</b>: converted value
   - \b -1: conversion in progress or failed
*/
int32_t ADC_GetValue (void) {
  return ((int32_t)HAL_ADC_GetValue(&ADC_INSTANCE_HANDLE));
}


/**
  \fn          uint32_t ADC_GetResolution (void)
  \brief       Get resolution of Analog-to-Digital Converter
  \returns     Resolution (in bits)
*/
uint32_t ADC_GetResolution (void) {
  return ADC_RESOLUTION;
}
